# Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.
""" git utility wrapper to execute it under specified system user. """
import os
import sys
import pwd
import subprocess
from plesk_exec import drop_privileges

import plesk_log; plesk_log.setDefaultLevel('warning')
log = plesk_log.getLogger(__name__)

usage="""Usage: gitmng <user> <working-dir> [<gitarg1> <gitarg2>...]
"""

def doMain(argv):
    if len(argv) < 3:
        print usage
        sys.exit(1)

    user = argv[1]
    workdir = argv[2]
    args = argv[3:]

    drop_privileges(user, "psacln")

    pw = pwd.getpwnam(user)
    os.environ["HOME"] = pw.pw_dir
    os.environ["PATH"] = "/usr/local/bin:/usr/local/sbin/:/usr/bin:/bin:/usr/sbin:/sbin"
    os.environ["GIT_SSH"] = "/usr/lib/plesk-9.0/git_ssh"
    os.environ["GIT_ASKPASS"] = "/bin/echo"     # Suppress password queries, git >= 1.7.1

    os.chdir(workdir)
    os.umask(022)

    try:
        sys.exit(subprocess.call(["git"] + args))
    except SystemExit:
        raise
    except Exception:
        log.error("Can't execute 'git' utility")
        raise

def main():
    try:
        doMain(sys.argv)
    except SystemExit:
        raise
    except Exception as ex:
        log.error('%s', ex)
        log.debug('This exception happened at:', exc_info=sys.exc_info())
        sys.exit(1)

if __name__ == '__main__':
    main()

# vim: ts=4 sts=4 sw=4 et :
