# Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.

import sys
from subprocess import Popen, PIPE
from optparse import OptionParser, OptionError

def read_options_list(filename):
    opts = []
    if filename is None or filename == "-":
        for line in sys.stdin:
            opts.append(line)
    else:
        with open(filename) as f:
            for line in f:
                opts.append(line)
    return opts

def show_options_values(phpcli, phpini, opts):
    php_code = "<?php\n$res = array();\n"
    for opt in opts:
        o = opt.strip()
        php_code += "$res['%s'] = ini_get('%s');\n" % (o, o)
    php_code += "echo serialize($res) . \"\\n\";\n"

    p = Popen([phpcli, "-c", phpini], stdin=PIPE)
    p.communicate(input=php_code)
    if p.returncode != 0:
        raise Exception("%s failed to execute: `%s`" % (phpcli, php_code))

def main():
    try:
        parser = OptionParser()
        parser.description = 'Utility for getting default php configuration settings in php-serialized format'
        parser.add_option('--cli-path', dest='cli_path', help='path to php interpreter')
        parser.add_option('--php-ini', dest='php_ini', help='path to php.ini')
        parser.add_option('--config', dest='config', help='file with list of directives. Use stdin if "-" or not specified')

        (options, args) = parser.parse_args()
        if not options.cli_path:
            parser.print_help()
            raise OptionError("PHP CLI path is not specified or empty", "--cli-path")
        if options.php_ini is None:
            parser.print_help()
            raise OptionError("php.ini path is not specified", "--php-ini")

        php_options = read_options_list(options.config)
        show_options_values(options.cli_path, options.php_ini, php_options)
    except Exception, e:
        sys.stderr.write("%s\n" % e)
        sys.exit(1)

if __name__ == "__main__":
    main()

# vim: ft=python ts=4 sts=4 sw=4 et :
