# Copyright 1999-2017. Parallels IP Holdings GmbH. All Rights Reserved.

import os
import sys
# import logging as log
import fileinput
import shutil
import plesk_subprocess as subprocess

def get_dhparams_path(dh_size):
    return "/opt/psa/etc/dhparams%d.pem" % dh_size

def generate_dh_params(dh_size, regenerate = False):
    dh_file = get_dhparams_path(dh_size)
    if regenerate or not os.path.isfile(dh_file):
        subprocess.check_call(["openssl", "dhparam", "-out", dh_file, str(dh_size)])

def config_set(pattern, value, config, prepend=None, append=None):
    found = False
    if not os.path.isfile(config):
        # create empty file
        open(config, "w").close()

    for line in fileinput.input(config, inplace=True):
        if not found and line.strip().startswith(pattern):
            found = True
            sys.stdout.write("%s\n" % value)
        else:
            sys.stdout.write(line)

    if not found:
        with open(config, 'a') as f:
            if prepend:
                f.write("%s\n" % prepend)
            f.write("%s\n" % value)
            if append:
                f.write("%s\n" % append)

def file_concat(dstfile, certfile, private_key = None, chained_certs = None):
    with open(dstfile, "w") as dst_obj:
        shutil.copyfileobj(open(certfile, "r"), dst_obj)

        if private_key and (private_key != certfile):
            shutil.copyfileobj(open(private_key, "r"), dst_obj)

        if chained_certs and (chained_certs != certfile):
            shutil.copyfileobj(open(chained_certs, "r"), dst_obj)

    os.chown(dstfile, 0, 0)
    os.chmod(dstfile, 0600)

def validate_cert(certfile, private_key=None, root_ca=None):
    try:
        # Getting hashsum of the certificate file
        out = subprocess.check_output(["openssl", "x509", "-noout", "-modulus", "-in", certfile], stderr=subprocess.PIPE)
        cert_hash = subprocess.check_output(["echo", out, "|", "openssl", "md5"])

        # Getting hashsum of the private key
        out = subprocess.check_output(["openssl", "rsa", "-noout", "-modulus", "-in", private_key if private_key else certfile], stderr=subprocess.PIPE)
        key_hash = subprocess.check_output(["echo", out, "|", "openssl", "md5"])

    except subprocess.CalledProcessError as e:
        raise Exception("%s" % e)

    if key_hash != cert_hash:
        raise Exception("A pair certificate + private key is not valid.")

    # Check chained certificate
    #try:
    #    out = subprocess.check_output(["openssl", "verify", "-CAfile", root_ca if root_ca else certfile, certfile], stderr=subprocess.PIPE)
    #    log.debug("* Verifying certificate: %s", out)
    #except subprocess.CalledProcessError as e:
    #    raise Exception("Certificate chain is not valid: %s" % e)
